==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/NumericRadiusAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericAxisBaseDescriptionMetadata } from "./NumericAxisBaseDescriptionMetadata";
import { NumericRadiusAxisDescription } from "./NumericRadiusAxisDescription";
/**
 * @hidden
 */
var NumericRadiusAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericRadiusAxisDescriptionMetadata, _super);
    function NumericRadiusAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericRadiusAxisDescriptionMetadata.b = function (a) {
        if (NumericRadiusAxisDescriptionMetadata.a == null) {
            NumericRadiusAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericRadiusAxisDescriptionMetadata.c(NumericRadiusAxisDescriptionMetadata.a);
        }
        if (a.g(NumericRadiusAxisDescriptionMetadata.a)) {
            return;
        }
        a.s(NumericRadiusAxisDescriptionMetadata.a);
    };
    NumericRadiusAxisDescriptionMetadata.c = function (a) {
        NumericAxisBaseDescriptionMetadata.c(a);
        a.item("RadiusExtentScale", "Number:double");
        a.item("InnerRadiusExtentScale", "Number:double");
    };
    NumericRadiusAxisDescriptionMetadata.d = function (a) {
        NumericRadiusAxisDescriptionMetadata.b(a);
        a.u("NumericRadiusAxis", function () { return new NumericRadiusAxisDescription(); });
        a.t("NumericRadiusAxis", NumericRadiusAxisDescriptionMetadata.a);
    };
    NumericRadiusAxisDescriptionMetadata.$t = markType(NumericRadiusAxisDescriptionMetadata, 'NumericRadiusAxisDescriptionMetadata');
    NumericRadiusAxisDescriptionMetadata.a = null;
    return NumericRadiusAxisDescriptionMetadata;
}(Base));
export { NumericRadiusAxisDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NumericRadiusAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericAxisBaseDescriptionMetadata } from "./NumericAxisBaseDescriptionMetadata";
import { NumericRadiusAxisDescription } from "./NumericRadiusAxisDescription";
/**
 * @hidden
 */
var NumericRadiusAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericRadiusAxisDescriptionMetadata, _super);
    function NumericRadiusAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericRadiusAxisDescriptionMetadata.b = function (a) {
        if (NumericRadiusAxisDescriptionMetadata.a == null) {
            NumericRadiusAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericRadiusAxisDescriptionMetadata.c(NumericRadiusAxisDescriptionMetadata.a);
        }
        if (a.j(NumericRadiusAxisDescriptionMetadata.a)) {
            return;
        }
        a.y(NumericRadiusAxisDescriptionMetadata.a);
    };
    NumericRadiusAxisDescriptionMetadata.c = function (a) {
        NumericAxisBaseDescriptionMetadata.c(a);
        a.item("RadiusExtentScale", "Number:double");
        a.item("InnerRadiusExtentScale", "Number:double");
    };
    NumericRadiusAxisDescriptionMetadata.d = function (a) {
        NumericRadiusAxisDescriptionMetadata.b(a);
        a.aa("NumericRadiusAxis", function () { return new NumericRadiusAxisDescription(); });
        a.z("NumericRadiusAxis", NumericRadiusAxisDescriptionMetadata.a);
    };
    NumericRadiusAxisDescriptionMetadata.$t = markType(NumericRadiusAxisDescriptionMetadata, 'NumericRadiusAxisDescriptionMetadata');
    NumericRadiusAxisDescriptionMetadata.a = null;
    return NumericRadiusAxisDescriptionMetadata;
}(Base));
export { NumericRadiusAxisDescriptionMetadata };
